.. image:: https://badge.fury.io/py/aiorpcX.svg
    :target: http://badge.fury.io/py/aiorpcX
.. image:: https://travis-ci.org/kyuupichan/aiorpcX.svg?branch=master
    :target: https://travis-ci.org/kyuupichan/aiorpcX
.. image:: https://coveralls.io/repos/github/kyuupichan/aiorpcX/badge.svg
    :target: https://coveralls.io/github/kyuupichan/aiorpcX

=======
aiorpcX
=======

A generic `asyncio <https://docs.python.org/3/library/asyncio.html>`_
library implementation of RPC suitable for an application that is a
client, server or both.

  :Licence: MIT
  :Language: Python (>= 3.6)
  :Author: Neil Booth

Documentation
=============

See `readthedocs <https://aiorpcX.readthedocs.io/>`_.
